==> zio-aws-macie2_2.13-5.17.295.9-sources.jar: zio/aws/macie2/model/StorageClass.scala <==
package zio.aws.macie2.model
import scala.jdk.CollectionConverters._
sealed trait StorageClass {
  def unwrap: software.amazon.awssdk.services.macie2.model.StorageClass
}
object StorageClass {
  def wrap(
      value: software.amazon.awssdk.services.macie2.model.StorageClass
  ): zio.aws.macie2.model.StorageClass = value match {
    case software.amazon.awssdk.services.macie2.model.StorageClass.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.STANDARD =>
      val r = STANDARD
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.REDUCED_REDUNDANCY =>
      val r = REDUCED_REDUNDANCY
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.STANDARD_IA =>
      val r = STANDARD_IA
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.INTELLIGENT_TIERING =>
      val r = INTELLIGENT_TIERING
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.DEEP_ARCHIVE =>
      val r = DEEP_ARCHIVE
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.ONEZONE_IA =>
      val r = ONEZONE_IA
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.GLACIER =>
      val r = GLACIER
      r
  }
  case object unknownToSdkVersion extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.UNKNOWN_TO_SDK_VERSION
  }
  case object STANDARD extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.STANDARD
  }
  case object REDUCED_REDUNDANCY extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.REDUCED_REDUNDANCY
  }
  case object STANDARD_IA extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.STANDARD_IA
  }
  case object INTELLIGENT_TIERING extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.INTELLIGENT_TIERING
  }
  case object DEEP_ARCHIVE extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.DEEP_ARCHIVE
  }
  case object ONEZONE_IA extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.ONEZONE_IA
  }
  case object GLACIER extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.GLACIER
  }
}

==> zio-aws-macie2_2.13-5.20.32.2-sources.jar: zio/aws/macie2/model/StorageClass.scala <==
package zio.aws.macie2.model
import scala.jdk.CollectionConverters._
sealed trait StorageClass {
  def unwrap: software.amazon.awssdk.services.macie2.model.StorageClass
}
object StorageClass {
  def wrap(
      value: software.amazon.awssdk.services.macie2.model.StorageClass
  ): zio.aws.macie2.model.StorageClass = value match {
    case software.amazon.awssdk.services.macie2.model.StorageClass.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.STANDARD =>
      val r = STANDARD
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.REDUCED_REDUNDANCY =>
      val r = REDUCED_REDUNDANCY
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.STANDARD_IA =>
      val r = STANDARD_IA
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.INTELLIGENT_TIERING =>
      val r = INTELLIGENT_TIERING
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.DEEP_ARCHIVE =>
      val r = DEEP_ARCHIVE
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.ONEZONE_IA =>
      val r = ONEZONE_IA
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.GLACIER =>
      val r = GLACIER
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.GLACIER_IR =>
      val r = GLACIER_IR
      r
    case software.amazon.awssdk.services.macie2.model.StorageClass.OUTPOSTS =>
      val r = OUTPOSTS
      r
  }
  case object unknownToSdkVersion extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.UNKNOWN_TO_SDK_VERSION
  }
  case object STANDARD extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.STANDARD
  }
  case object REDUCED_REDUNDANCY extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.REDUCED_REDUNDANCY
  }
  case object STANDARD_IA extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.STANDARD_IA
  }
  case object INTELLIGENT_TIERING extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.INTELLIGENT_TIERING
  }
  case object DEEP_ARCHIVE extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.DEEP_ARCHIVE
  }
  case object ONEZONE_IA extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.ONEZONE_IA
  }
  case object GLACIER extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.GLACIER
  }
  case object GLACIER_IR extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.GLACIER_IR
  }
  case object OUTPOSTS extends zio.aws.macie2.model.StorageClass {
    override def unwrap
        : software.amazon.awssdk.services.macie2.model.StorageClass =
      software.amazon.awssdk.services.macie2.model.StorageClass.OUTPOSTS
  }
}
